#!/usr/bin/python

# libraries
import serial
import time
import os

PRINT = True
CYCLETIME = 2.0	# time between display updates
DISPCLR = chr(254) + chr(1) # clear the display
DISPON = chr(254) + chr(12) # turn display on
DISPOFF = chr(254) + chr(8) # turn display off
DISPL1 = chr(254) + chr(2) # send cursor home (line 1)
DISPL2 = chr(254) + chr(192) # start line 2
CGSTART = 64 # start register of CGRAM
FUELMIN = 3.5
COMMSWARN = 100 # over this number of comms errors the display will show a warning flasher


# Files
FUELFILE = '/home/pi/obd/fuel.txt'
FUELDELTAFILE = '/home/pi/obd/fueldelta.txt'
KLAFILE = '/home/pi/obd/kla.txt'
KLIFILE = '/home/pi/obd/kli.txt'
ECTFILE = '/home/pi/obd/ect.txt'
GEARFILE = '/home/pi/obd/gear.txt'
VOLTFILE = '/home/pi/obd/voltage.txt'
OILERFILE = '/home/pi/obd/oiler.txt'
COMMFILE = '/home/pi/obd/commerror.txt'

# Procedures
def errorlog(MESSAGE):
	if PRINT:
		print(MESSAGE)
        return

ser0 = serial.Serial(
port='/dev/serial/by-id/usb-Prolific_Technology_Inc._USB-Serial_Controller-if00-port0',
baudrate=9600,
parity=serial.PARITY_NONE,
stopbits=serial.STOPBITS_ONE,
bytesize=serial.EIGHTBITS,
dsrdtr=None,
rtscts=None
)

LINE1=DISPL1 + "STARTING"

ser0.write(LINE1)

time.sleep(3)

try:
	FILE = open(COMMFILE, 'r')
      	COMMSINIT = int(FILE.read())
       	FILE.close()
except:
	COMMSINIT = 0

LINE1=DISPL1 + "Init.COMMS " + str(COMMSINIT)

ser0.write(LINE1)

time.sleep(3)


FLASHER = " "

while True:
        try:
                FILE = open(FUELFILE,'r')
                FUEL = float(FILE.read())
                FILE.close()
        except:
                errorlog("Failed to read FUEL file")
                FUEL = 0.0

	try:
        	FILE = open(FUELDELTAFILE,'r')
        	FUELDELTA = float(FILE.read())
        	FILE.close()
	except:
        	errorlog("Failed to read FUELDELTA file")
        	FUELDELTA = 0.0
        try:
                FILE = open(KLIFILE,'r')
                KLI = float(FILE.read())
                FILE.close()
        except:
                errorlog("Failed to read KLI file")
                KLI = 0.0

	try:
        	FILE = open(KLAFILE,'r')
        	KLA = float(FILE.read())
        	FILE.close()
	except:
        	errorlog("Failed to read KLA file")
        	KLA = 30.0

	try:
        	FILE = open(ECTFILE,'r')
        	ECT = float(FILE.read())
        	FILE.close()
	except:
        	errorlog("Failed to read ECT file")
		ECT = 0.0

	try:
        	FILE = open(VOLTFILE,'r')
        	VOLTAGE = float(FILE.read())
        	FILE.close()
	except:
        	errorlog("Failed to read VOLT file")
		VOLTAGE = 0.0
        try:
                FILE = open(OILERFILE,'r')
                OILER = float(FILE.read())
                FILE.close()
        except:
                errorlog("Failed to read OILER file")
                OILER = 0.0
        try:
                FILE = open(GEARFILE,'r')
                GEAR = FILE.read()
		GEAR = GEAR[:1]
                FILE.close()
        except:
                errorlog("Failed to read OILER file")
                GEAR = "-"

# Process the data before displaying it
	if FUELDELTA > 0:
		FUEL = FUELMIN - FUELDELTA

	LINE1 =  DISPL1 + GEAR + " "
	LINE1 += ('%3.0f' % ECT) + "c "
	LINE1 += ('%2.0f' % KLI) + "  "
	LINE1 += ('%4.1f' % FUEL) + "L"

	LINE2 = DISPL2  + FLASHER +('%4.0f' % OILER) + "% " 
        LINE2 += ('%2.0f' % KLA) + "a "
 	LINE2 += ('%3.0f' % (KLA * FUEL)) + "km"

	ser0.write(DISPL1)
	ser0.write(LINE1 + LINE2)
        ser0.flushOutput()
	time.sleep(CYCLETIME)	

        if FLASHER == " ":
		try:
			FILE = open(COMMFILE, 'r')
		      	COMMS = int(FILE.read())
		       	FILE.close()
		except:
			COMMS = COMMSINIT

		if COMMS - COMMSINIT > COMMSWARN:
			FLASHER = "X"
		else:
	        	FLASHER = "-"
        else:
		FLASHER = " "


