#!/usr/bin/python
# This program uses a Yocto-Voltage sensor
# to measure the voltage across the fuel tank level resistor.
# It then consults a look-up table to determine the fuel level
# The engine must be running so that the bike voltage is consistant.


import time
import datetime
import os,sys


# add ../../Sources to the PYTHONPATH
sys.path.append(os.path.join("/home/pi/yocto/Sources"))
from yocto_api import *
from yocto_voltage import *

# Set variables
PRINT = True
CHECK = 5 # no.of seconds between checks
DELTA = 0.01 # amount to adjust fuel level on each scan
MAXDIFF = 3.5 # change in fuel level reqd to bypass smoothing
CORRFILE = "/home/pi/obd/volt-level.txt" # file with correlation btw disch time and fuel level
FUELFILE = "/home/pi/obd/fuel.txt" # file with current fuel level
VOLTFILE = "/home/pi/obd/sensorvolt.txt" # file with current sensor voltage
RPMFILE = "/home/pi/obd/rpm.txt" # file with RPM data. Only check fuel level with engine running (voltage)
SENSORLOG = "/home/pi/obd/sensorlog.txt" # file with log of tank sensor voltage
SENSOR = 0 # voltage measured

errmsg=YRefParam()

# Setup the API to use local USB devices
if YAPI.RegisterHub("usb", errmsg)!= YAPI.SUCCESS:
    sys.exit("init error"+errmsg.value)

# Set the YoctoVolt module info
sensorDC= YVoltage.FindVoltage('VOLTAGE1-4D4B6.voltage1')

try:
	FILE = open(FUELFILE,'r')
	FUELA = float(FILE.read())
	FILE.close()
except:
	FUELA = 20.0

while (True):
	time.sleep(CHECK)
	try:
		FILE = open(RPMFILE, 'r') # check if engine is running
		RPM = float(FILE.read())
		FILE.close()
	except:
		FILE.close()
		RPM = 0

	if RPM > 0:
		if (sensorDC.isOnline()):
			SENSOR = float(sensorDC.get_currentValue())
			ACTIVATE = 1
		else:
			ACTIVATE = 0


		if ACTIVATE == 1: # we have a reading
			FILE = open(CORRFILE,'r') # read the volts/fuel correlation file
			A = FILE.read().split()
			FILE.close()
			for i in range(0,len(A),2): 
        			if SENSOR < float(A[i]): # find the points either side of the reading and interpolate
                			FUELI = float(A[i-1])- (SENSOR - float(A[i-2])) * (float(A[i-1]) - float(A[i+1]))/(float(A[i]) - float(A[i-2]))

					if FUELA != "":
						if abs(FUELI - FUELA) <  MAXDIFF: # fuel up check
						
							if FUELI > FUELA:
								FUELA += DELTA
							else:
								FUELA -= DELTA
						else:
							FUELA = FUELI
					try:
						FILE = open(FUELFILE,'w')
						FILE.write('%.2f' % FUELA)
						FILE.close()
					except:
						if PRINT:
							print "Failed to write FUEL file"
					try:
						FILE = open(VOLTFILE,'w')
						FILE.write('%.2f' % SENSOR)
						FILE.close()
					except:
						if PRINT:
							print "Failed to write DTIME"
                                        try:
                                                FILE = open(SENSORLOG,'a')
                                                FILE.write('%.2f' % SENSOR)
						FILE.write("\n")
                                                FILE.close()
                                        except:
                                                if PRINT:
                                                        print "Failed to write SENSORLOG"
					if PRINT:
                				print "Voltage :",'%.2f' % SENSOR
						print "Avg fuel:", '%.2f' % FUELA
						print "Inst Fuel :", '%.2f' % FUELI, "\n"
						
					

		                	break
		else:
			if PRINT:
                		print "Input did not activate \n\n"

	
			
	
